@@ -1,5 +1,5 @@
 from .ldm import LatentDiffusion
-from .utils import seed_everything, save_wave, get_time
+from .utils import seed_everything, save_wave, get_time, get_duration
 from .pipeline import *
 
 import os
